You are viewing a plain text version of this content. The canonical link for it is here.
Posted to java-dev@axis.apache.org by di...@apache.org on 2007/02/07 23:06:04 UTC

svn commit: r504712 [1/2] - in /webservices/axis2/trunk/java/modules/jaxws: ./ src/org/apache/axis2/jaxws/client/ test/org/apache/axis2/jaxws/anytype/tests/ test/org/apache/axis2/jaxws/attachments/ test/org/apache/axis2/jaxws/client/ test/org/apache/ax...

Author: dims
Date: Wed Feb  7 14:06:01 2007
New Revision: 504712

URL: http://svn.apache.org/viewvc?view=rev&rev=504712
Log:
flatten the tests, much easier to run each test separately.

Added:
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/DOMSourceDispatchTest.java   (contents, props changed)
      - copied, changed from r504631, webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/DOMSourceDispatch.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/JAXBDispatchTest.java   (contents, props changed)
      - copied, changed from r504631, webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/JAXBDispatch.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/JAXBSourceDispatchTest.java   (contents, props changed)
      - copied, changed from r504631, webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/JAXBSourceDispatch.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/SAXSourceDispatchTest.java   (contents, props changed)
      - copied, changed from r504631, webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/SAXSourceDispatch.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/SOAP12DispatchTests.java   (contents, props changed)
      - copied, changed from r504631, webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/SOAP12Dispatch.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/SOAPMessageDispatchTest.java   (contents, props changed)
      - copied, changed from r504631, webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/SOAPMessageDispatch.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/StreamSourceDispatchTest.java   (contents, props changed)
      - copied, changed from r504631, webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/StreamSourceDispatch.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/StringDispatchTest.java   (contents, props changed)
      - copied, changed from r504631, webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/StringDispatch.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/framework/AbstractTestCase.java
Removed:
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/DOMSourceDispatch.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/DispatchTestSuite.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/JAXBDispatch.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/JAXBSourceDispatch.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/SAXSourceDispatch.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/SOAP12Dispatch.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/SOAPMessageDispatch.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/StreamSourceDispatch.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/StringDispatch.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/framework/JAXWSTest.java
Modified:
    webservices/axis2/trunk/java/modules/jaxws/pom.xml
    webservices/axis2/trunk/java/modules/jaxws/project.xml
    webservices/axis2/trunk/java/modules/jaxws/src/org/apache/axis2/jaxws/client/JAXBDispatch.java
    webservices/axis2/trunk/java/modules/jaxws/src/org/apache/axis2/jaxws/client/XMLDispatch.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/anytype/tests/AnyTypeTests.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/attachments/MTOMSerializationTests.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/client/ClientConfigTests.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/client/DispatchSoapActionTests.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/client/PropertyValueTests.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/client/ProxySoapActionTests.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/databinding/BindingToProtocolTests.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/description/AnnotationDescriptionTests.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/description/GetDescFromBindingProviderTests.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/description/PortSelectionTests.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/description/ServiceTests.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/description/WSDLDescriptionTests.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/description/WSDLTests.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/exception/ExceptionFactoryTests.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/handler/HandlerChainProcessorTests.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/i18n/JaxwsMessageBundleTests.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/injection/ResourceInjectionTests.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/lifecycle/EndpointLifecycleTests.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/message/BlockTests.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/message/FaultTests.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/message/MessageTests.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/message/SAAJConverterTests.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/message/SOAP12Tests.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/message/XMLStreamReaderSplitterTests.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/nonanonymous/complextype/NonAnonymousComplexTypeTests.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/polymorphic/shape/tests/PolymorphicTests.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/provider/JAXBProviderTests.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/provider/ProviderTestCase.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/provider/SoapMessageProviderTests.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/provider/SourceMessageProviderTests.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/provider/SourceProviderTests.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/provider/StringMessageProviderTests.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/provider/StringProviderTests.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/proxy/GorillaDLWProxyTests.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/proxy/ProxyNonWrappedTests.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/proxy/ProxyTests.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/proxy/RPCProxyTests.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/proxy/SOAP12ProxyTests.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/sample/AddNumbersTests.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/sample/AddressBookTests.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/sample/BareTests.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/sample/FaultsServiceTests.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/sample/FaultyWebServiceTests.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/sample/MtomSampleByteArrayTests.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/sample/MtomSampleTests.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/sample/NonWrapTests.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/sample/ParallelAsyncTests.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/sample/WSGenTests.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/sample/WrapTests.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/sample/wsgen/client/WSGenService.java
    webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/security/BasicAuthSecurityTests.java

Modified: webservices/axis2/trunk/java/modules/jaxws/pom.xml
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/jaxws/pom.xml?view=diff&rev=504712&r1=504711&r2=504712
==============================================================================
--- webservices/axis2/trunk/java/modules/jaxws/pom.xml (original)
+++ webservices/axis2/trunk/java/modules/jaxws/pom.xml Wed Feb  7 14:06:01 2007
@@ -713,7 +713,8 @@
   		<configuration>
   			<skip>false</skip>
   			<includes>
-           	 <include>**/*Test.java</include>
+           	 <include>org/**/*Test.java</include>
+           	 <include>org/**/*Tests.java</include>
             </includes>
                       <systemProperties>
             <property>

Modified: webservices/axis2/trunk/java/modules/jaxws/project.xml
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/jaxws/project.xml?view=diff&rev=504712&r1=504711&r2=504712
==============================================================================
--- webservices/axis2/trunk/java/modules/jaxws/project.xml (original)
+++ webservices/axis2/trunk/java/modules/jaxws/project.xml Wed Feb  7 14:06:01 2007
@@ -79,6 +79,7 @@
         <unitTest>
             <includes>
                 <include>**/*Test.java</include>
+                <include>**/*Tests.java</include>
             </includes>
 
             <resources>

Modified: webservices/axis2/trunk/java/modules/jaxws/src/org/apache/axis2/jaxws/client/JAXBDispatch.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/jaxws/src/org/apache/axis2/jaxws/client/JAXBDispatch.java?view=diff&rev=504712&r1=504711&r2=504712
==============================================================================
--- webservices/axis2/trunk/java/modules/jaxws/src/org/apache/axis2/jaxws/client/XMLDispatch.java (original)
+++ webservices/axis2/trunk/java/modules/jaxws/src/org/apache/axis2/jaxws/client/XMLDispatch.java Wed Feb  7 14:06:01 2007
@@ -173,7 +173,7 @@
 				   value = message.getAsSOAPMessage();
 				   
 			   } else {
-                   // NOTE Similar code in JAXBDispatch
+                   // NOTE Similar code in JAXBDispatchTest
                    
 				   // TODO: This doesn't seem right to me. We should not have an intermediate StringBlock.  
 				   // This is not performant. Scheu 

Modified: webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/anytype/tests/AnyTypeTests.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/anytype/tests/AnyTypeTests.java?view=diff&rev=504712&r1=504711&r2=504712
==============================================================================
--- webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/anytype/tests/AnyTypeTests.java (original)
+++ webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/anytype/tests/AnyTypeTests.java Wed Feb  7 14:06:01 2007
@@ -19,11 +19,18 @@
 package org.apache.axis2.jaxws.anytype.tests;
 
 import junit.framework.TestCase;
+import junit.framework.Test;
+import junit.framework.TestSuite;
 import org.apache.axis2.jaxws.anytype.sei.AnyTypeMessagePortType;
 import org.apache.axis2.jaxws.anytype.sei.AnyTypeMessageService;
+import org.apache.axis2.jaxws.framework.AbstractTestCase;
 
-public class AnyTypeTests extends TestCase {
+public class AnyTypeTests extends AbstractTestCase {
 	
+    public static Test suite() {
+        return getTestSetup(new TestSuite(AnyTypeTests.class));
+    }
+
 	public void testAnyTypeElementinWrappedWSDL(){
 		System.out.println("------------------------------");
 		System.out.println("Test : "+getName());

Modified: webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/attachments/MTOMSerializationTests.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/attachments/MTOMSerializationTests.java?view=diff&rev=504712&r1=504711&r2=504712
==============================================================================
--- webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/attachments/MTOMSerializationTests.java (original)
+++ webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/attachments/MTOMSerializationTests.java Wed Feb  7 14:06:01 2007
@@ -12,6 +12,8 @@
 import javax.xml.bind.JAXBContext;
 
 import junit.framework.TestCase;
+import junit.framework.Test;
+import junit.framework.TestSuite;
 import org.apache.axiom.om.OMAbstractFactory;
 import org.apache.axiom.om.OMElement;
 import org.apache.axiom.om.OMFactory;
@@ -31,11 +33,12 @@
 import org.apache.axis2.jaxws.message.factory.MessageFactory;
 import org.apache.axis2.jaxws.provider.DataSourceImpl;
 import org.apache.axis2.jaxws.registry.FactoryRegistry;
+import org.apache.axis2.jaxws.framework.AbstractTestCase;
 import org.test.mtom.ImageDepot;
 import org.test.mtom.ObjectFactory;
 import org.test.mtom.SendImage;
 
-public class MTOMSerializationTests extends TestCase {
+public class MTOMSerializationTests extends AbstractTestCase {
 
     private DataSource imageDS;
     
@@ -53,6 +56,10 @@
         super(name);
     }
     
+    public static Test suite() {
+        return getTestSetup(new TestSuite(MTOMSerializationTests.class));
+    }
+
     /*
      * Simulate building up an OM that is sourced from JAXB and contains
      * binary data that should be optimized when serialized.  

Modified: webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/client/ClientConfigTests.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/client/ClientConfigTests.java?view=diff&rev=504712&r1=504711&r2=504712
==============================================================================
--- webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/client/ClientConfigTests.java (original)
+++ webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/client/ClientConfigTests.java Wed Feb  7 14:06:01 2007
@@ -11,13 +11,20 @@
 import javax.xml.ws.WebServiceException;
 
 import junit.framework.TestCase;
+import junit.framework.Test;
+import junit.framework.TestSuite;
+import org.apache.axis2.jaxws.framework.AbstractTestCase;
 
-public class ClientConfigTests extends TestCase {
+public class ClientConfigTests extends AbstractTestCase {
 
     public ClientConfigTests(String name) {
         super(name);
     }
     
+    public static Test suite() {
+        return getTestSetup(new TestSuite(ClientConfigTests.class));
+    }
+
     public void testBadWsdlUrl() throws Exception {
         
         URL url = null;

Modified: webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/client/DispatchSoapActionTests.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/client/DispatchSoapActionTests.java?view=diff&rev=504712&r1=504711&r2=504712
==============================================================================
--- webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/client/DispatchSoapActionTests.java (original)
+++ webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/client/DispatchSoapActionTests.java Wed Feb  7 14:06:01 2007
@@ -27,7 +27,10 @@
 import javax.xml.ws.Service.Mode;
 
 import junit.framework.TestCase;
+import junit.framework.Test;
+import junit.framework.TestSuite;
 import org.apache.axis2.jaxws.BindingProvider;
+import org.apache.axis2.jaxws.framework.AbstractTestCase;
 import org.apache.axis2.jaxws.client.soapaction.BookStoreService;
 import org.apache.axis2.jaxws.client.soapaction.GetPriceResponseType;
 import org.apache.axis2.jaxws.client.soapaction.GetPriceType;
@@ -36,11 +39,15 @@
 /**
  * A suite of SOAPAction related tests for the dispatch client 
  */
-public class DispatchSoapActionTests extends TestCase {
+public class DispatchSoapActionTests extends AbstractTestCase {
     
     private static final String targetNamespace = "http://jaxws.axis2.apache.org/client/soapaction";
     private static final String portName = "BookStorePort";
         
+    public static Test suite() {
+        return getTestSetup(new TestSuite(DispatchSoapActionTests.class));
+    }
+
     /**
      * Invoke an operation this is defined in the WSDL as having a SOAPAction.
      * Since this is a Dispatch client, we'll need to specify that SOAPAction

Modified: webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/client/PropertyValueTests.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/client/PropertyValueTests.java?view=diff&rev=504712&r1=504711&r2=504712
==============================================================================
--- webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/client/PropertyValueTests.java (original)
+++ webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/client/PropertyValueTests.java Wed Feb  7 14:06:01 2007
@@ -28,16 +28,23 @@
 import javax.xml.ws.WebServiceException;
 
 import junit.framework.TestCase;
+import junit.framework.Test;
+import junit.framework.TestSuite;
+import org.apache.axis2.jaxws.framework.AbstractTestCase;
 
 /**
  * A suite to test the validation of the client request/response context properties
  */
-public class PropertyValueTests extends TestCase {
+public class PropertyValueTests extends AbstractTestCase {
     
     public PropertyValueTests(String name) {
         super(name);
     }
     
+    public static Test suite() {
+        return getTestSetup(new TestSuite(PropertyValueTests.class));
+    }
+
     public void testSetInvalidClientProperties() throws Exception {
         Service svc = Service.create(new QName("http://test", "TestService"));
         QName portQName = new QName("http://test", "TestPort");

Modified: webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/client/ProxySoapActionTests.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/client/ProxySoapActionTests.java?view=diff&rev=504712&r1=504711&r2=504712
==============================================================================
--- webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/client/ProxySoapActionTests.java (original)
+++ webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/client/ProxySoapActionTests.java Wed Feb  7 14:06:01 2007
@@ -19,18 +19,25 @@
 package org.apache.axis2.jaxws.client;
 
 import junit.framework.TestCase;
+import junit.framework.Test;
+import junit.framework.TestSuite;
 import org.apache.axis2.jaxws.client.soapaction.BookStore;
 import org.apache.axis2.jaxws.client.soapaction.BookStoreService;
+import org.apache.axis2.jaxws.framework.AbstractTestCase;
 
 /**
  * A suite of SOAPAction related tests for the dynamic proxy client 
  */
-public class ProxySoapActionTests extends TestCase {
+public class ProxySoapActionTests extends AbstractTestCase {
     
     public ProxySoapActionTests(String name) {
         super(name);
     }
     
+    public static Test suite() {
+        return getTestSetup(new TestSuite(DispatchSoapActionTests.class));
+    }
+
     public void testSendRequestWithSoapAction() {
         System.out.println("----------------------------------");
         System.out.println("test: " + getName());

Modified: webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/databinding/BindingToProtocolTests.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/databinding/BindingToProtocolTests.java?view=diff&rev=504712&r1=504711&r2=504712
==============================================================================
--- webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/databinding/BindingToProtocolTests.java (original)
+++ webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/databinding/BindingToProtocolTests.java Wed Feb  7 14:06:01 2007
@@ -21,13 +21,16 @@
 import javax.xml.namespace.QName;
 
 import junit.framework.TestCase;
+import junit.framework.Test;
+import junit.framework.TestSuite;
+import org.apache.axis2.jaxws.framework.AbstractTestCase;
 
 /**
  * A suite of tests for reading the binding from a WSDL file and
  * making sure we are configuring the Protocol correctly for 
  * messages based on that binding ID.
  */
-public class BindingToProtocolTests extends TestCase {
+public class BindingToProtocolTests extends AbstractTestCase {
     
     private static final String SOAP11_TEST_NS = "http://jaxws.axis2.apache.org/bindingtest/soap11";
     private static final String SOAP12_TEST_NS = "http://jaxws.axis2.apache.org/bindingtest/soap12";
@@ -38,6 +41,10 @@
         super(name);
     }
     
+    public static Test suite() {
+        return getTestSetup(new TestSuite(BindingToProtocolTests.class));
+    }
+
     /**
      * Test to see if we can read the SOAP 1.1 binding transport URL
      * in a WSDL, as specified by JAX-WS section 10.4.1.

Modified: webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/description/AnnotationDescriptionTests.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/description/AnnotationDescriptionTests.java?view=diff&rev=504712&r1=504711&r2=504712
==============================================================================
--- webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/description/AnnotationDescriptionTests.java (original)
+++ webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/description/AnnotationDescriptionTests.java Wed Feb  7 14:06:01 2007
@@ -24,7 +24,10 @@
 import javax.xml.ws.Service;
 
 import junit.framework.TestCase;
+import junit.framework.Test;
+import junit.framework.TestSuite;
 import org.apache.axis2.jaxws.spi.ServiceDelegate;
+import org.apache.axis2.jaxws.framework.AbstractTestCase;
 
 /**
  * Directly test the Description classes built via annotations without a WSDL file.
@@ -33,9 +36,13 @@
  * - A generated service (annotations)
  * - An SEI
  */
-public class AnnotationDescriptionTests extends TestCase {
+public class AnnotationDescriptionTests extends AbstractTestCase {
     
-    /* 
+    public static Test suite() {
+        return getTestSetup(new TestSuite(AnnotationDescriptionTests.class));
+    }
+
+    /*
      * ========================================================================
      * ServiceDescription Tests
      * ========================================================================

Modified: webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/description/GetDescFromBindingProviderTests.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/description/GetDescFromBindingProviderTests.java?view=diff&rev=504712&r1=504711&r2=504712
==============================================================================
--- webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/description/GetDescFromBindingProviderTests.java (original)
+++ webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/description/GetDescFromBindingProviderTests.java Wed Feb  7 14:06:01 2007
@@ -26,9 +26,12 @@
 import javax.xml.ws.Service;
 
 import junit.framework.TestCase;
+import junit.framework.Test;
+import junit.framework.TestSuite;
 import org.apache.axis2.description.AxisService;
 import org.apache.axis2.jaxws.spi.BindingProvider;
 import org.apache.axis2.jaxws.spi.ServiceDelegate;
+import org.apache.axis2.jaxws.framework.AbstractTestCase;
 import org.apache.ws.axis2.tests.EchoPort;
 
 /**
@@ -37,10 +40,14 @@
  * gotten from the EndpointDesc.  Note that the BindingProvider class is NOT
  * the jaxws API one; it is the internal implementation BindingProvider class.
  */
-public class GetDescFromBindingProviderTests extends TestCase {
+public class GetDescFromBindingProviderTests extends AbstractTestCase {
     
     private static final String wsdlSOAPAddress = "http://localhost:8080/axis2/services/EchoService";
     
+    public static Test suite() {
+        return getTestSetup(new TestSuite(GetDescFromBindingProviderTests.class));
+    }
+
     public void testForProxy() {
         String namespaceURI = "http://ws.apache.org/axis2/tests";
         String localPart = "EchoService";

Modified: webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/description/PortSelectionTests.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/description/PortSelectionTests.java?view=diff&rev=504712&r1=504711&r2=504712
==============================================================================
--- webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/description/PortSelectionTests.java (original)
+++ webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/description/PortSelectionTests.java Wed Feb  7 14:06:01 2007
@@ -29,18 +29,25 @@
 import javax.xml.ws.WebServiceException;
 
 import junit.framework.TestCase;
+import junit.framework.Test;
+import junit.framework.TestSuite;
 import org.apache.axis2.jaxws.sample.addnumbers.AddNumbersPortType;
 import org.apache.axis2.jaxws.spi.BindingProvider;
 import org.apache.axis2.jaxws.spi.ServiceDelegate;
+import org.apache.axis2.jaxws.framework.AbstractTestCase;
 import org.apache.ws.axis2.tests.EchoPort;
 
 /**
  * 
  */
-public class PortSelectionTests extends TestCase {
+public class PortSelectionTests extends AbstractTestCase {
     private static String VALID_SERVICE_NAMESPACE = "http://org/test/addnumbers";
     private static String VALID_SERVICE_LOCALPART_3 = "AddNumbersService3";
     
+    public static Test suite() {
+        return getTestSetup(new TestSuite(ServiceTests.class));
+    }
+
     public void testServiceDescPortSelectionMethods() {
         URL wsdlURL = DescriptionTestUtils2.getWSDLURL("WSDLMultiTests.wsdl");
 

Modified: webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/description/ServiceTests.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/description/ServiceTests.java?view=diff&rev=504712&r1=504711&r2=504712
==============================================================================
--- webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/description/ServiceTests.java (original)
+++ webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/description/ServiceTests.java Wed Feb  7 14:06:01 2007
@@ -29,10 +29,13 @@
 import javax.xml.ws.WebServiceException;
 
 import junit.framework.TestCase;
+import junit.framework.Test;
+import junit.framework.TestSuite;
 import org.apache.axis2.jaxws.sample.addnumbers.AddNumbersPortType;
 import org.apache.axis2.jaxws.spi.ServiceDelegate;
+import org.apache.axis2.jaxws.framework.AbstractTestCase;
 
-public class ServiceTests extends TestCase {
+public class ServiceTests extends AbstractTestCase {
     private static String VALID_SERVICE_NAMESPACE = "http://org/test/addnumbers";
     private static String VALID_SERVICE_LOCALPART_1 = "AddNumbersService1";
     private static String VALID_SERVICE_LOCALPART_2 = "AddNumbersService2";
@@ -43,6 +46,10 @@
     private static String VALID_PORT_S2P2 = "AddNumbersPortS2P2";
     private static String VALID_PORT_S2P3 = "AddNumbersPortS2P3";
     private static String VALID_PORT_S2P4 = "AddNumbersPortS2P4";
+
+    public static Test suite() {
+        return getTestSetup(new TestSuite(ServiceTests.class));
+    }
 
     public void testInvalidServiceNamespace() {
         URL wsdlURL = DescriptionTestUtils2.getWSDLURL("WSDLMultiTests.wsdl");

Modified: webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/description/WSDLDescriptionTests.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/description/WSDLDescriptionTests.java?view=diff&rev=504712&r1=504711&r2=504712
==============================================================================
--- webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/description/WSDLDescriptionTests.java (original)
+++ webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/description/WSDLDescriptionTests.java Wed Feb  7 14:06:01 2007
@@ -34,13 +34,16 @@
 import javax.xml.ws.WebServiceException;
 
 import junit.framework.TestCase;
+import junit.framework.Test;
+import junit.framework.TestSuite;
 import org.apache.axis2.jaxws.spi.ServiceDelegate;
+import org.apache.axis2.jaxws.framework.AbstractTestCase;
 import org.apache.ws.axis2.tests.EchoPort;
 
 /**
  * Directly test the Description classes built with a WSDL file.
  */
-public class WSDLDescriptionTests extends TestCase {
+public class WSDLDescriptionTests extends AbstractTestCase {
     
     private Service service;
     private ServiceDelegate serviceDelegate;
@@ -51,6 +54,10 @@
     private QName validPortQName = new QName(VALID_NAMESPACE, VALID_PORT);
 
     
+    public static Test suite() {
+        return getTestSetup(new TestSuite(WSDLTests.class));
+    }
+
     protected void setUp() {
         // Create a new service for each test to test various valid and invalid
         // flows

Modified: webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/description/WSDLTests.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/description/WSDLTests.java?view=diff&rev=504712&r1=504711&r2=504712
==============================================================================
--- webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/description/WSDLTests.java (original)
+++ webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/description/WSDLTests.java Wed Feb  7 14:06:01 2007
@@ -25,7 +25,10 @@
 import javax.xml.ws.WebServiceException;
 
 import junit.framework.TestCase;
+import junit.framework.Test;
+import junit.framework.TestSuite;
 import org.apache.axis2.jaxws.spi.ServiceDelegate;
+import org.apache.axis2.jaxws.framework.AbstractTestCase;
 
 /**
  * Tests building a ServiceDescription using WSDL and the JAXWS Service API.  
@@ -33,8 +36,12 @@
  * that should be used, this test will create Service objects and then use introspection
  * to check the underlying ServiceDelegate which contains the ServiceDescription.
  */
-public class WSDLTests extends TestCase {
+public class WSDLTests extends AbstractTestCase {
     
+    public static Test suite() {
+        return getTestSetup(new TestSuite(WSDLTests.class));
+    }
+
     public void testValidWSDLService() {
         Service service = null;
         ServiceDelegate serviceDelegate = null;

Copied: webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/DOMSourceDispatchTest.java (from r504631, webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/DOMSourceDispatch.java)
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/DOMSourceDispatchTest.java?view=diff&rev=504712&p1=webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/DOMSourceDispatch.java&r1=504631&p2=webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/DOMSourceDispatchTest.java&r2=504712
==============================================================================
--- webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/DOMSourceDispatch.java (original)
+++ webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/DOMSourceDispatchTest.java Wed Feb  7 14:06:01 2007
@@ -33,7 +33,10 @@
 import javax.xml.ws.WebServiceException;
 
 import junit.framework.TestCase;
+import junit.framework.Test;
+import junit.framework.TestSuite;
 import org.apache.axis2.jaxws.message.util.Reader2Writer;
+import org.apache.axis2.jaxws.framework.AbstractTestCase;
 import org.w3c.dom.Document;
 import org.w3c.dom.Node;
 
@@ -41,10 +44,14 @@
  * This class tests the JAX-WS Dispatch with various forms of the 
  * javax.xml.transform.dom.DOMSource 
  */
-public class DOMSourceDispatch extends TestCase{
+public class DOMSourceDispatchTest extends AbstractTestCase {
 
     private static final XMLInputFactory inputFactory = XMLInputFactory.newInstance();
     
+    public static Test suite() {
+        return getTestSetup(new TestSuite(DOMSourceDispatchTest.class));
+    }
+
     public void testSyncPayloadMode() throws Exception {
 		System.out.println("---------------------------------------");
         System.out.println("test: " + getName());

Propchange: webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/DOMSourceDispatchTest.java
------------------------------------------------------------------------------
    svn:eol-style = native

Copied: webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/JAXBDispatchTest.java (from r504631, webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/JAXBDispatch.java)
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/JAXBDispatchTest.java?view=diff&rev=504712&p1=webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/JAXBDispatch.java&r1=504631&p2=webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/JAXBDispatchTest.java&r2=504712
==============================================================================
--- webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/JAXBDispatch.java (original)
+++ webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/JAXBDispatchTest.java Wed Feb  7 14:06:01 2007
@@ -27,22 +27,28 @@
 
 import org.xmlsoap.schemas.soap.envelope.Body;
 import org.xmlsoap.schemas.soap.envelope.Envelope;
+import org.apache.axis2.jaxws.framework.AbstractTestCase;
 
-import junit.framework.TestCase;
+import junit.framework.Test;
+import junit.framework.TestSuite;
 import test.EchoString;
 import test.EchoStringResponse;
 import test.ObjectFactory;
 
-public class JAXBDispatch extends TestCase {
+public class JAXBDispatchTest extends AbstractTestCase {
 
     private Dispatch<Object> dispatchPayload;
     private Dispatch<Object> dispatchMessage;
     private JAXBContext jbc;
     
-    public JAXBDispatch(String name) {
+    public JAXBDispatchTest(String name) {
         super(name);
     }
     
+    public static Test suite() {
+        return getTestSetup(new TestSuite(JAXBDispatchTest.class));
+    }
+
     public void setUp() throws Exception {
         //Create the Service object
         Service svc = Service.create(DispatchTestConstants.QNAME_SERVICE);

Propchange: webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/JAXBDispatchTest.java
------------------------------------------------------------------------------
    svn:eol-style = native

Copied: webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/JAXBSourceDispatchTest.java (from r504631, webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/JAXBSourceDispatch.java)
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/JAXBSourceDispatchTest.java?view=diff&rev=504712&p1=webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/JAXBSourceDispatch.java&r1=504631&p2=webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/JAXBSourceDispatchTest.java&r2=504712
==============================================================================
--- webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/JAXBSourceDispatch.java (original)
+++ webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/JAXBSourceDispatchTest.java Wed Feb  7 14:06:01 2007
@@ -31,9 +31,11 @@
 import javax.xml.ws.Dispatch;
 import javax.xml.ws.Service;
 
-import junit.framework.TestCase;
+import junit.framework.Test;
+import junit.framework.TestSuite;
 import org.test.dispatch.jaxbsource.Invoke;
 import org.test.dispatch.jaxbsource.ObjectFactory;
+import org.apache.axis2.jaxws.framework.AbstractTestCase;
 
 /*
 * This is a test case for Invoking Dispatch with a JAXBSource.
@@ -42,7 +44,7 @@
 */
 
 
-public class JAXBSourceDispatch extends TestCase {
+public class JAXBSourceDispatchTest extends AbstractTestCase {
 	/**
      * Invoke a sync Dispatch<JAXBSource> in PAYLOAD mode
      */
@@ -51,6 +53,10 @@
 	private QName serviceName = new QName("http://ws.apache.org/axis2", "SourceProviderService");
 	private QName portName =new QName("http://ws.apache.org/axis2", "SimpleProviderServiceSOAP11port0");
 	
+    public static Test suite() {
+        return getTestSetup(new TestSuite(JAXBSourceDispatchTest.class));
+    }
+
     public void testJAXBSourceSyncPayloadMode() throws Exception {
         System.out.println("---------------------------------------");
         System.out.println("test: " + getName());

Propchange: webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/JAXBSourceDispatchTest.java
------------------------------------------------------------------------------
    svn:eol-style = native

Copied: webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/SAXSourceDispatchTest.java (from r504631, webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/SAXSourceDispatch.java)
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/SAXSourceDispatchTest.java?view=diff&rev=504712&p1=webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/SAXSourceDispatch.java&r1=504631&p2=webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/SAXSourceDispatchTest.java&r2=504712
==============================================================================
--- webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/SAXSourceDispatch.java (original)
+++ webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/SAXSourceDispatchTest.java Wed Feb  7 14:06:01 2007
@@ -31,17 +31,24 @@
 import javax.xml.ws.WebServiceException;
 
 import junit.framework.TestCase;
+import junit.framework.Test;
+import junit.framework.TestSuite;
 import org.apache.axis2.jaxws.message.util.Reader2Writer;
+import org.apache.axis2.jaxws.framework.AbstractTestCase;
 import org.xml.sax.InputSource;
 
 /**
  * This class tests the JAX-WS Dispatch<Source> with content in various 
  * forms of a javax.xml.transform.sax.SAXSource.
  */
-public class SAXSourceDispatch extends TestCase{
+public class SAXSourceDispatchTest extends AbstractTestCase {
 
     private static final XMLInputFactory inputFactory = XMLInputFactory.newInstance();
     
+    public static Test suite() {
+        return getTestSetup(new TestSuite(SAXSourceDispatchTest.class));
+    }
+
 	public void testSyncPayloadMode() throws Exception {
 		System.out.println("---------------------------------------");
 		System.out.println("test: " + getName());

Propchange: webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/SAXSourceDispatchTest.java
------------------------------------------------------------------------------
    svn:eol-style = native

Copied: webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/SOAP12DispatchTests.java (from r504631, webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/SOAP12Dispatch.java)
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/SOAP12DispatchTests.java?view=diff&rev=504712&p1=webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/SOAP12Dispatch.java&r1=504631&p2=webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/SOAP12DispatchTests.java&r2=504712
==============================================================================
--- webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/SOAP12Dispatch.java (original)
+++ webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/SOAP12DispatchTests.java Wed Feb  7 14:06:01 2007
@@ -33,12 +33,15 @@
 import javax.xml.ws.soap.SOAPBinding;
 
 import junit.framework.TestCase;
+import junit.framework.Test;
+import junit.framework.TestSuite;
+import org.apache.axis2.jaxws.framework.AbstractTestCase;
 
 /**
  * This class uses the JAX-WS Dispatch API to test sending and receiving
  * messages using SOAP 1.2.
  */
-public class SOAP12Dispatch extends TestCase {
+public class SOAP12DispatchTests extends AbstractTestCase {
     
     private static final QName QNAME_SERVICE = new QName(
             "http://org/apache/axis2/jaxws/test/SOAP12", "SOAP12Service");
@@ -60,10 +63,14 @@
         sampleRequest + 
         sampleEnvelopeTail;
     
-    public SOAP12Dispatch(String name) {
+    public SOAP12DispatchTests(String name) {
         super(name);
     }
     
+    public static Test suite() {
+        return getTestSetup(new TestSuite(SOAP12DispatchTests.class));
+    }
+
     /**
      * Test sending a SOAP 1.2 request in PAYLOAD mode
      */

Propchange: webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/SOAP12DispatchTests.java
------------------------------------------------------------------------------
    svn:eol-style = native

Copied: webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/SOAPMessageDispatchTest.java (from r504631, webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/SOAPMessageDispatch.java)
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/SOAPMessageDispatchTest.java?view=diff&rev=504712&p1=webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/SOAPMessageDispatch.java&r1=504631&p2=webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/SOAPMessageDispatchTest.java&r2=504712
==============================================================================
--- webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/SOAPMessageDispatch.java (original)
+++ webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/SOAPMessageDispatchTest.java Wed Feb  7 14:06:01 2007
@@ -29,9 +29,11 @@
 import javax.xml.ws.Response;
 import javax.xml.ws.Service;
 
-import junit.framework.TestCase;
+import junit.framework.Test;
+import junit.framework.TestSuite;
+import org.apache.axis2.jaxws.framework.AbstractTestCase;
 
-public class SOAPMessageDispatch extends TestCase {
+public class SOAPMessageDispatchTest extends AbstractTestCase {
 	private String url = "http://localhost:8080/axis2/services/ProxyDocLitWrappedService";
 	private QName serviceName = new QName(
 			"http://org.apache.axis2.proxy.doclitwrapped", "ProxyDocLitWrappedService");
@@ -40,6 +42,10 @@
 	
 	String messageResource = "test-resources" + File.separator  + "xml" + File.separator +"soapmessage.xml";
 	
+    public static Test suite() {
+        return getTestSetup(new TestSuite(SOAPMessageDispatchTest.class));
+    }
+
 	public void testSOAPMessageSyncMessageMode() throws Exception {
 		
         String basedir = new File(System.getProperty("basedir",".")).getAbsolutePath();

Propchange: webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/SOAPMessageDispatchTest.java
------------------------------------------------------------------------------
    svn:eol-style = native

Copied: webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/StreamSourceDispatchTest.java (from r504631, webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/StreamSourceDispatch.java)
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/StreamSourceDispatchTest.java?view=diff&rev=504712&p1=webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/StreamSourceDispatch.java&r1=504631&p2=webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/StreamSourceDispatchTest.java&r2=504712
==============================================================================
--- webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/StreamSourceDispatch.java (original)
+++ webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/StreamSourceDispatchTest.java Wed Feb  7 14:06:01 2007
@@ -31,18 +31,24 @@
 import javax.xml.ws.Service;
 import javax.xml.ws.Service.Mode;
 
-import junit.framework.TestCase;
+import junit.framework.Test;
+import junit.framework.TestSuite;
 import org.apache.axis2.jaxws.message.util.Reader2Writer;
+import org.apache.axis2.jaxws.framework.AbstractTestCase;
 
 /**
  * This class tests the JAX-WS Dispatch<Source> functionality with various
  * forms of a StreamSource object. 
  *
  */
-public class StreamSourceDispatch extends TestCase {
+public class StreamSourceDispatchTest extends AbstractTestCase {
 
     private static XMLInputFactory inputFactory = XMLInputFactory.newInstance();
     
+    public static Test suite() {
+        return getTestSetup(new TestSuite(StreamSourceDispatchTest.class));
+    }
+
 	/**
      * Invoke a Dispatch<Source> synchronously with the content in PAYLOAD mode.
 	 */

Propchange: webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/StreamSourceDispatchTest.java
------------------------------------------------------------------------------
    svn:eol-style = native

Copied: webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/StringDispatchTest.java (from r504631, webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/StringDispatch.java)
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/StringDispatchTest.java?view=diff&rev=504712&p1=webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/StringDispatch.java&r1=504631&p2=webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/StringDispatchTest.java&r2=504712
==============================================================================
--- webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/StringDispatch.java (original)
+++ webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/StringDispatchTest.java Wed Feb  7 14:06:01 2007
@@ -28,9 +28,15 @@
 import javax.xml.ws.Service;
 import javax.xml.ws.WebServiceException;
 
-import junit.framework.TestCase;
+import junit.framework.Test;
+import junit.framework.TestSuite;
+import org.apache.axis2.jaxws.framework.AbstractTestCase;
 
-public class StringDispatch extends TestCase {
+public class StringDispatchTest extends AbstractTestCase {
+
+    public static Test suite() {
+        return getTestSetup(new TestSuite(StringDispatchTest.class));
+    }
 
     /**
      * Invoke a sync Dispatch<String> in PAYLOAD mode

Propchange: webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/dispatch/StringDispatchTest.java
------------------------------------------------------------------------------
    svn:eol-style = native

Modified: webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/exception/ExceptionFactoryTests.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/exception/ExceptionFactoryTests.java?view=diff&rev=504712&r1=504711&r2=504712
==============================================================================
--- webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/exception/ExceptionFactoryTests.java (original)
+++ webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/exception/ExceptionFactoryTests.java Wed Feb  7 14:06:01 2007
@@ -20,12 +20,15 @@
 import javax.xml.ws.WebServiceException;
 
 import junit.framework.TestCase;
+import junit.framework.Test;
+import junit.framework.TestSuite;
 import org.apache.axis2.jaxws.ExceptionFactory;
+import org.apache.axis2.jaxws.framework.AbstractTestCase;
 
 /**
  * Tests the ExceptionFactory
  */
-public class ExceptionFactoryTests extends TestCase {
+public class ExceptionFactoryTests extends AbstractTestCase {
 	private static final String sampleText = "Sample";
 
     /**
@@ -35,6 +38,10 @@
         super(name);
     }
     
+    public static Test suite() {
+        return getTestSetup(new TestSuite(ExceptionFactoryTests.class));
+    }
+
     /**
      * @teststrategy Tests creation of a WebServiceException
      */

Added: webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/framework/AbstractTestCase.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/framework/AbstractTestCase.java?view=auto&rev=504712
==============================================================================
--- webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/framework/AbstractTestCase.java (added)
+++ webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/framework/AbstractTestCase.java Wed Feb  7 14:06:01 2007
@@ -0,0 +1,32 @@
+package org.apache.axis2.jaxws.framework;
+
+import junit.framework.TestCase;
+import junit.framework.Test;
+import junit.framework.TestSuite;
+import junit.extensions.TestSetup;
+
+public abstract class AbstractTestCase extends TestCase {
+
+    public AbstractTestCase() {
+        super(AbstractTestCase.class.getName());
+    }
+
+    public AbstractTestCase(java.lang.String string) {
+        super(string);
+    }
+
+    protected static Test getTestSetup(Test test) {
+        return new TestSetup(test) {
+            public void setUp() {
+                System.out.println("Starting the server.");
+                StartServer startServer = new StartServer("server1");
+                startServer.testStartServer();
+            }
+            public void tearDown() {
+                System.out.println("Stopping the server");
+                StopServer stopServer = new StopServer("server1");
+                stopServer.testStopServer();
+            }
+        };
+    }
+}

Modified: webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/handler/HandlerChainProcessorTests.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/handler/HandlerChainProcessorTests.java?view=diff&rev=504712&r1=504711&r2=504712
==============================================================================
--- webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/handler/HandlerChainProcessorTests.java (original)
+++ webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/handler/HandlerChainProcessorTests.java Wed Feb  7 14:06:01 2007
@@ -25,7 +25,11 @@
 import javax.xml.ws.handler.soap.SOAPHandler;
 
 import junit.framework.TestCase;
+import junit.framework.Test;
+import junit.framework.TestSuite;
 import org.apache.axis2.jaxws.core.MessageContext;
+import org.apache.axis2.jaxws.description.ServiceTests;
+import org.apache.axis2.jaxws.framework.AbstractTestCase;
 
 /*
  * There are myriad scenarios to test here:
@@ -43,7 +47,7 @@
  * The testHandleFault_* methods test the HandlerChainProcessor.processFault() method
  * 
  */
-public class HandlerChainProcessorTests extends TestCase {
+public class HandlerChainProcessorTests extends AbstractTestCase {
 
 	// String result is how we'll verify the right methods from
 	// the Handler implementations were called
@@ -63,6 +67,10 @@
 
 	ArrayList<Handler> handlers = new ArrayList<Handler>();
 	
+    public static Test suite() {
+        return getTestSetup(new TestSuite(HandlerChainProcessorTests.class));
+    }
+
 	@Override
 	protected void setUp() throws Exception {
 		// HandlerChainProcessor expects a sorted chain

Modified: webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/i18n/JaxwsMessageBundleTests.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/i18n/JaxwsMessageBundleTests.java?view=diff&rev=504712&r1=504711&r2=504712
==============================================================================
--- webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/i18n/JaxwsMessageBundleTests.java (original)
+++ webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/i18n/JaxwsMessageBundleTests.java Wed Feb  7 14:06:01 2007
@@ -17,12 +17,15 @@
 package org.apache.axis2.jaxws.i18n;
 
 import junit.framework.TestCase;
+import junit.framework.Test;
+import junit.framework.TestSuite;
+import org.apache.axis2.jaxws.framework.AbstractTestCase;
 
 /**
  * Tests basic function of the Message Bundle
  *
  */
-public class JaxwsMessageBundleTests extends TestCase {
+public class JaxwsMessageBundleTests extends AbstractTestCase {
     
     public JaxwsMessageBundleTests() { 
         super();
@@ -32,6 +35,10 @@
         super(arg);   
     }
     
+    public static Test suite() {
+        return getTestSetup(new TestSuite(JaxwsMessageBundleTests.class));
+    }
+
     /**
      * @testStrategy: Test that the resource bundle
      * is installed by obtaining a message

Modified: webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/injection/ResourceInjectionTests.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/injection/ResourceInjectionTests.java?view=diff&rev=504712&r1=504711&r2=504712
==============================================================================
--- webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/injection/ResourceInjectionTests.java (original)
+++ webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/injection/ResourceInjectionTests.java Wed Feb  7 14:06:01 2007
@@ -21,13 +21,16 @@
 import javax.xml.ws.WebServiceContext;
 
 import junit.framework.TestCase;
+import junit.framework.Test;
+import junit.framework.TestSuite;
 import org.apache.axis2.jaxws.context.WebServiceContextImpl;
 import org.apache.axis2.jaxws.resourceinjection.sei.ResourceInjectionPortType;
 import org.apache.axis2.jaxws.resourceinjection.sei.ResourceInjectionService;
 import org.apache.axis2.jaxws.server.endpoint.injection.ResourceInjector;
 import org.apache.axis2.jaxws.server.endpoint.injection.factory.ResourceInjectionFactory;
+import org.apache.axis2.jaxws.framework.AbstractTestCase;
 
-public class ResourceInjectionTests extends TestCase {
+public class ResourceInjectionTests extends AbstractTestCase {
 
 
 	private Object resource = new WebServiceContextImpl();
@@ -35,6 +38,10 @@
 		super();
 		// TODO Auto-generated constructor stub
 	}
+
+    public static Test suite() {
+        return getTestSetup(new TestSuite(ResourceInjectionTests.class));
+    }
 
 	public void testInjectionOnField(){
 		Object serviceInstance = new ResourceInjectionTestImpl1();

Modified: webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/lifecycle/EndpointLifecycleTests.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/lifecycle/EndpointLifecycleTests.java?view=diff&rev=504712&r1=504711&r2=504712
==============================================================================
--- webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/lifecycle/EndpointLifecycleTests.java (original)
+++ webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/lifecycle/EndpointLifecycleTests.java Wed Feb  7 14:06:01 2007
@@ -19,12 +19,15 @@
 package org.apache.axis2.jaxws.lifecycle;
 
 import junit.framework.TestCase;
+import junit.framework.Test;
+import junit.framework.TestSuite;
 import org.apache.axis2.jaxws.registry.FactoryRegistry;
 import org.apache.axis2.jaxws.resourceinjection.ResourceInjectionPortTypeImpl;
 import org.apache.axis2.jaxws.server.endpoint.lifecycle.EndpointLifecycleManager;
 import org.apache.axis2.jaxws.server.endpoint.lifecycle.factory.EndpointLifecycleManagerFactory;
+import org.apache.axis2.jaxws.framework.AbstractTestCase;
 
-public class EndpointLifecycleTests extends TestCase {
+public class EndpointLifecycleTests extends AbstractTestCase {
 	Object endpointInstance = new ResourceInjectionPortTypeImpl();
 	Object badObject = new Object();
 	public EndpointLifecycleTests() {
@@ -40,6 +43,10 @@
 		// TODO Auto-generated constructor stub
 	}
 	
+    public static Test suite() {
+        return getTestSetup(new TestSuite(EndpointLifecycleTests.class));
+    }
+
 	public void testPostConstruct(){
 		System.out.println("------------------------------");
 		System.out.println("Test : "+getName());

Modified: webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/message/BlockTests.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/message/BlockTests.java?view=diff&rev=504712&r1=504711&r2=504712
==============================================================================
--- webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/message/BlockTests.java (original)
+++ webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/message/BlockTests.java Wed Feb  7 14:06:01 2007
@@ -39,6 +39,8 @@
 import javax.xml.transform.stream.StreamSource;
 
 import junit.framework.TestCase;
+import junit.framework.Test;
+import junit.framework.TestSuite;
 import org.apache.axiom.om.OMElement;
 import org.apache.axiom.om.OMOutputFormat;
 import org.apache.axiom.om.impl.builder.StAXOMBuilder;
@@ -52,6 +54,7 @@
 import org.apache.axis2.jaxws.message.factory.XMLStringBlockFactory;
 import org.apache.axis2.jaxws.message.util.Reader2Writer;
 import org.apache.axis2.jaxws.registry.FactoryRegistry;
+import org.apache.axis2.jaxws.framework.AbstractTestCase;
 import org.w3c.dom.Document;
 import org.w3c.dom.Node;
 import org.xml.sax.InputSource;
@@ -63,7 +66,7 @@
  * Tests to create and validate blocks.
  * These are not client/server tests.
  */
-public class BlockTests extends TestCase {
+public class BlockTests extends AbstractTestCase {
 
 	// String test variables
 	private static final String sampleText =
@@ -87,6 +90,10 @@
 		super(arg0);
 	}
 	
+    public static Test suite() {
+        return getTestSetup(new TestSuite(BlockTests.class));
+    }
+
 	/**
 	 * Create a Block representing an XMLString and simulate a 
 	 * normal Dispatch<String> flow

Modified: webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/message/FaultTests.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/message/FaultTests.java?view=diff&rev=504712&r1=504711&r2=504712
==============================================================================
--- webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/message/FaultTests.java (original)
+++ webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/message/FaultTests.java Wed Feb  7 14:06:01 2007
@@ -23,17 +23,20 @@
 import javax.xml.stream.XMLStreamReader;
 
 import junit.framework.TestCase;
+import junit.framework.Test;
+import junit.framework.TestSuite;
 import org.apache.axiom.om.OMElement;
 import org.apache.axiom.soap.impl.builder.StAXSOAPModelBuilder;
 import org.apache.axis2.jaxws.message.factory.MessageFactory;
 import org.apache.axis2.jaxws.registry.FactoryRegistry;
+import org.apache.axis2.jaxws.framework.AbstractTestCase;
 
 /**
  * MessageTests
  * Tests to create and validate Message processing
  * These are not client/server tests.
  */
-public class FaultTests extends TestCase {
+public class FaultTests extends AbstractTestCase {
 
 	private static final String faultString = "Internal server error from WAS";
 	
@@ -94,6 +97,10 @@
 		super(arg0);
 	}
 	
+    public static Test suite() {
+        return getTestSetup(new TestSuite(FaultTests.class));
+    }
+
 	/**
 	 * This test effectively tests XMLFault construction from
 	 * 

Modified: webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/message/MessageTests.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/message/MessageTests.java?view=diff&rev=504712&r1=504711&r2=504712
==============================================================================
--- webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/message/MessageTests.java (original)
+++ webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/message/MessageTests.java Wed Feb  7 14:06:01 2007
@@ -26,6 +26,8 @@
 import javax.xml.stream.XMLStreamReader;
 
 import junit.framework.TestCase;
+import junit.framework.Test;
+import junit.framework.TestSuite;
 import org.apache.axiom.om.OMElement;
 import org.apache.axiom.om.OMOutputFormat;
 import org.apache.axiom.om.impl.llom.OMSourcedElementImpl;
@@ -37,6 +39,7 @@
 import org.apache.axis2.jaxws.message.factory.XMLStringBlockFactory;
 import org.apache.axis2.jaxws.message.util.SAAJConverter;
 import org.apache.axis2.jaxws.registry.FactoryRegistry;
+import org.apache.axis2.jaxws.framework.AbstractTestCase;
 import test.EchoStringResponse;
 import test.ObjectFactory;
 
@@ -46,7 +49,7 @@
  * These are not client/server tests.  Instead the tests simulate the processing of a Message during
  * client/server processing.
  */
-public class MessageTests extends TestCase {
+public class MessageTests extends AbstractTestCase {
 
 	// String test variables
 	private static final String soap11env = "http://schemas.xmlsoap.org/soap/envelope/";
@@ -128,8 +131,12 @@
 	public MessageTests(String arg0) {
 		super(arg0);
 	}
-	
-	/**
+
+    public static Test suite() {
+        return getTestSetup(new TestSuite(MessageTests.class));
+    }
+
+    /**
 	 * Create a Block representing an XMLString and simulate a 
 	 * normal Dispatch<String> flow.
      * In addition the test makes sure that the XMLString block is not

Modified: webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/message/SAAJConverterTests.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/message/SAAJConverterTests.java?view=diff&rev=504712&r1=504711&r2=504712
==============================================================================
--- webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/message/SAAJConverterTests.java (original)
+++ webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/message/SAAJConverterTests.java Wed Feb  7 14:06:01 2007
@@ -29,6 +29,8 @@
 import javax.xml.stream.XMLStreamReader;
 
 import junit.framework.TestCase;
+import junit.framework.Test;
+import junit.framework.TestSuite;
 import org.apache.axiom.om.OMAbstractFactory;
 import org.apache.axiom.om.OMElement;
 import org.apache.axiom.om.OMFactory;
@@ -37,6 +39,7 @@
 import org.apache.axis2.jaxws.message.factory.SAAJConverterFactory;
 import org.apache.axis2.jaxws.message.util.SAAJConverter;
 import org.apache.axis2.jaxws.registry.FactoryRegistry;
+import org.apache.axis2.jaxws.framework.AbstractTestCase;
 
 /**
  * SAAJConverterTests
@@ -46,7 +49,7 @@
  * the converter.
  *
  */
-public class SAAJConverterTests extends TestCase {
+public class SAAJConverterTests extends AbstractTestCase {
 
 	private static final String sampleText =
 		"<pre:a xmlns:pre=\"urn://sample\">" +
@@ -69,6 +72,10 @@
 	public SAAJConverterTests(String arg0) {
 		super(arg0);
 	}
+
+    public static Test suite() {
+        return getTestSetup(new TestSuite(SAAJConverterTests.class));
+    }
 
 	/**
 	 * @testStrategy Tests conversions between SAAJ and OM SOAPEnvelopes

Modified: webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/message/SOAP12Tests.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/message/SOAP12Tests.java?view=diff&rev=504712&r1=504711&r2=504712
==============================================================================
--- webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/message/SOAP12Tests.java (original)
+++ webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/message/SOAP12Tests.java Wed Feb  7 14:06:01 2007
@@ -22,6 +22,8 @@
 import javax.xml.stream.XMLStreamReader;
 
 import junit.framework.TestCase;
+import junit.framework.Test;
+import junit.framework.TestSuite;
 import org.apache.axiom.om.OMElement;
 import org.apache.axiom.om.OMNamespace;
 import org.apache.axiom.soap.SOAPEnvelope;
@@ -30,13 +32,14 @@
 import org.apache.axis2.jaxws.message.factory.XMLStringBlockFactory;
 import org.apache.axis2.jaxws.message.util.Reader2Writer;
 import org.apache.axis2.jaxws.registry.FactoryRegistry;
+import org.apache.axis2.jaxws.framework.AbstractTestCase;
 
 /**
  * This suite is used to test the creation of messages based on SOAP 1.2
  * with both inbound and outbound simulations. 
  *
  */
-public class SOAP12Tests extends TestCase {
+public class SOAP12Tests extends AbstractTestCase {
 
     private static final String sampleText = 
         "<echo>test string</echo>";
@@ -62,6 +65,10 @@
         super(name);
     }
     
+    public static Test suite() {
+        return getTestSetup(new TestSuite(SOAP12Tests.class));
+    }
+
     /**
      * Simulate creating a SOAP 1.2 message when the business object
      * provided is just the payload. 

Modified: webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/message/XMLStreamReaderSplitterTests.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/message/XMLStreamReaderSplitterTests.java?view=diff&rev=504712&r1=504711&r2=504712
==============================================================================
--- webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/message/XMLStreamReaderSplitterTests.java (original)
+++ webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/message/XMLStreamReaderSplitterTests.java Wed Feb  7 14:06:01 2007
@@ -27,13 +27,16 @@
 import javax.xml.stream.XMLStreamWriter;
 
 import junit.framework.TestCase;
+import junit.framework.Test;
+import junit.framework.TestSuite;
 import org.apache.axis2.jaxws.message.util.Reader2Writer;
 import org.apache.axis2.jaxws.message.util.XMLStreamReaderSplitter;
+import org.apache.axis2.jaxws.framework.AbstractTestCase;
 
 /**
  * Tests XMLStreamReaderSplitter
  */
-public class XMLStreamReaderSplitterTests extends TestCase {
+public class XMLStreamReaderSplitterTests extends AbstractTestCase {
 
 	// String test variables
 	private static final String sampleText =
@@ -64,6 +67,10 @@
 		super(arg0);
 	}
 	
+    public static Test suite() {
+        return getTestSetup(new TestSuite(XMLStreamReaderSplitterTests.class));
+    }
+
 	/**
 	 * Test XMLStreamReaderSplitter 
 	 * @throws Exception

Modified: webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/nonanonymous/complextype/NonAnonymousComplexTypeTests.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/nonanonymous/complextype/NonAnonymousComplexTypeTests.java?view=diff&rev=504712&r1=504711&r2=504712
==============================================================================
--- webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/nonanonymous/complextype/NonAnonymousComplexTypeTests.java (original)
+++ webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/nonanonymous/complextype/NonAnonymousComplexTypeTests.java Wed Feb  7 14:06:01 2007
@@ -6,10 +6,13 @@
 import javax.xml.ws.WebServiceException;
 
 import junit.framework.TestCase;
+import junit.framework.Test;
+import junit.framework.TestSuite;
 import org.apache.axis2.jaxws.nonanonymous.complextype.sei.EchoMessagePortType;
 import org.apache.axis2.jaxws.nonanonymous.complextype.sei.EchoMessageService;
+import org.apache.axis2.jaxws.framework.AbstractTestCase;
 
-public class NonAnonymousComplexTypeTests extends TestCase {
+public class NonAnonymousComplexTypeTests extends AbstractTestCase {
 
 	/**
 	 * 
@@ -26,6 +29,11 @@
 		super(arg0);
 		// TODO Auto-generated constructor stub
 	}
+
+    public static Test suite() {
+        return getTestSetup(new TestSuite(NonAnonymousComplexTypeTests.class));
+    }
+
 	public void testSimpleProxy() {
 		System.out.println("------------------------------");
 		System.out.println("Test : "+getName());

Modified: webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/polymorphic/shape/tests/PolymorphicTests.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/polymorphic/shape/tests/PolymorphicTests.java?view=diff&rev=504712&r1=504711&r2=504712
==============================================================================
--- webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/polymorphic/shape/tests/PolymorphicTests.java (original)
+++ webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/polymorphic/shape/tests/PolymorphicTests.java Wed Feb  7 14:06:01 2007
@@ -12,17 +12,24 @@
 import javax.wsdl.WSDLException;
 
 import junit.framework.TestCase;
+import junit.framework.Test;
+import junit.framework.TestSuite;
 import org.apache.axis2.jaxws.polymorphic.shape.sei.PolymorphicShapePortType;
 import org.apache.axis2.jaxws.polymorphic.shape.sei.PolymorphicShapeService;
 import org.apache.axis2.jaxws.util.WSDL4JWrapper;
 import org.apache.axis2.jaxws.util.WSDLWrapper;
 import org.apache.axis2.jaxws.wsdl.SchemaReaderException;
 import org.apache.axis2.jaxws.wsdl.impl.SchemaReaderImpl;
+import org.apache.axis2.jaxws.framework.AbstractTestCase;
 import org.test.shape.Shape;
 import org.test.shape.Square;
 import org.test.shape.threed.ThreeDSquare;
 
-public class PolymorphicTests extends TestCase {
+public class PolymorphicTests extends AbstractTestCase {
+
+    public static Test suite() {
+        return getTestSetup(new TestSuite(PolymorphicTests.class));
+    }
 
 	public void testFormalAndActualTypeInDifferentPackages(){
 		System.out.println("------------------------------");

Modified: webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/provider/JAXBProviderTests.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/provider/JAXBProviderTests.java?view=diff&rev=504712&r1=504711&r2=504712
==============================================================================
--- webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/provider/JAXBProviderTests.java (original)
+++ webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/provider/JAXBProviderTests.java Wed Feb  7 14:06:01 2007
@@ -34,6 +34,8 @@
 import org.test.mtom.ObjectFactory;
 import org.test.mtom.SendImage;
 import org.test.mtom.SendImageResponse;
+import junit.framework.Test;
+import junit.framework.TestSuite;
 
 /**
  * The intended purpose of this testcase is to test the MTOM functions in Axis2. 
@@ -62,6 +64,10 @@
     private QName serviceName = new QName("http://ws.apache.org/axis2", "JAXBProviderService");
     DataSource stringDS, imageDS;
     
+    public static Test suite() {
+        return getTestSetup(new TestSuite(JAXBProviderTests.class));
+    }
+
     protected void setUp() throws Exception {
         super.setUp();
         

Modified: webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/provider/ProviderTestCase.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/provider/ProviderTestCase.java?view=diff&rev=504712&r1=504711&r2=504712
==============================================================================
--- webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/provider/ProviderTestCase.java (original)
+++ webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/provider/ProviderTestCase.java Wed Feb  7 14:06:01 2007
@@ -21,8 +21,9 @@
 import javax.xml.namespace.QName;
 
 import junit.framework.TestCase;
+import org.apache.axis2.jaxws.framework.AbstractTestCase;
 
-public abstract class ProviderTestCase extends TestCase {
+public abstract class ProviderTestCase extends AbstractTestCase {
 
     public QName portName = new QName("http://ws.apache.org/axis2", "SimpleProviderServiceSOAP11port0");
     public String providerResourceDir = "test-resources"+File.separator+"provider";

Modified: webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/provider/SoapMessageProviderTests.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/provider/SoapMessageProviderTests.java?view=diff&rev=504712&r1=504711&r2=504712
==============================================================================
--- webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/provider/SoapMessageProviderTests.java (original)
+++ webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/provider/SoapMessageProviderTests.java Wed Feb  7 14:06:01 2007
@@ -38,6 +38,8 @@
 import javax.xml.ws.soap.SOAPFaultException;
 
 import org.apache.axis2.jaxws.provider.soapmsg.SoapMessageProvider;
+import junit.framework.Test;
+import junit.framework.TestSuite;
 
 /**
  * Tests Dispatch<SOAPMessage> client and a Provider<SOAPMessage> service.
@@ -81,7 +83,11 @@
     SoapMessageProvider.XML_WSE_REQUEST +
     "</invoke_str></ns2:invoke>";
                 
-    
+
+    public static Test suite() {
+        return getTestSetup(new TestSuite(SoapMessageProviderTests.class));
+    }
+
     protected void setUp() throws Exception {
             super.setUp();
     }

Modified: webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/provider/SourceMessageProviderTests.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/provider/SourceMessageProviderTests.java?view=diff&rev=504712&r1=504711&r2=504712
==============================================================================
--- webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/provider/SourceMessageProviderTests.java (original)
+++ webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/provider/SourceMessageProviderTests.java Wed Feb  7 14:06:01 2007
@@ -16,6 +16,9 @@
  */
 package org.apache.axis2.jaxws.provider;
 
+import junit.framework.Test;
+import junit.framework.TestSuite;
+
 import java.io.File;
 import java.io.FileInputStream;
 import java.io.InputStream;
@@ -32,6 +35,9 @@
     private QName serviceName = new QName("http://ws.apache.org/axis2", "SourceMessageProviderService");
     private String xmlDir = "xml";
 
+    public static Test suite() {
+        return getTestSetup(new TestSuite(SourceMessageProviderTests.class));
+    }
 
     protected void setUp() throws Exception {
             super.setUp();

Modified: webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/provider/SourceProviderTests.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/provider/SourceProviderTests.java?view=diff&rev=504712&r1=504711&r2=504712
==============================================================================
--- webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/provider/SourceProviderTests.java (original)
+++ webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/provider/SourceProviderTests.java Wed Feb  7 14:06:01 2007
@@ -16,6 +16,9 @@
  */
 package org.apache.axis2.jaxws.provider;
 
+import junit.framework.Test;
+import junit.framework.TestSuite;
+
 import java.io.ByteArrayInputStream;
 import java.io.File;
 import java.io.FileInputStream;
@@ -41,6 +44,9 @@
     private QName serviceName = new QName("http://ws.apache.org/axis2", "SourceProviderService");
     private String xmlDir = "xml";
 
+    public static Test suite() {
+        return getTestSetup(new TestSuite(SourceProviderTests.class));
+    }
 
     protected void setUp() throws Exception {
             super.setUp();

Modified: webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/provider/StringMessageProviderTests.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/provider/StringMessageProviderTests.java?view=diff&rev=504712&r1=504711&r2=504712
==============================================================================
--- webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/provider/StringMessageProviderTests.java (original)
+++ webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/provider/StringMessageProviderTests.java Wed Feb  7 14:06:01 2007
@@ -16,6 +16,9 @@
  */
 package org.apache.axis2.jaxws.provider;
 
+import junit.framework.Test;
+import junit.framework.TestSuite;
+
 import javax.xml.namespace.QName;
 import javax.xml.ws.Dispatch;
 import javax.xml.ws.Service;
@@ -25,6 +28,10 @@
     String endpointUrl = "http://localhost:8080/axis2/services/StringMessageProviderService";
     String xmlString = "<invoke>test input</invoke>";
     private QName serviceName = new QName("http://ws.apache.org/axis2", "StringMessageProviderService");
+
+    public static Test suite() {
+        return getTestSetup(new TestSuite(StringMessageProviderTests.class));
+    }
 
     protected void setUp() throws Exception {
             super.setUp();

Modified: webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/provider/StringProviderTests.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/provider/StringProviderTests.java?view=diff&rev=504712&r1=504711&r2=504712
==============================================================================
--- webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/provider/StringProviderTests.java (original)
+++ webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/provider/StringProviderTests.java Wed Feb  7 14:06:01 2007
@@ -16,6 +16,9 @@
  */
 package org.apache.axis2.jaxws.provider;
 
+import junit.framework.Test;
+import junit.framework.TestSuite;
+
 import javax.xml.namespace.QName;
 import javax.xml.soap.SOAPFault;
 import javax.xml.ws.BindingProvider;
@@ -42,6 +45,10 @@
         super(name);
     }
     
+    public static Test suite() {
+        return getTestSetup(new TestSuite(StringProviderTests.class));
+    }
+
     private Dispatch<String> getDispatch() {
         Service svc = Service.create(serviceName);
         svc.addPort(portName, null, endpointUrl);

Modified: webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/proxy/GorillaDLWProxyTests.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/proxy/GorillaDLWProxyTests.java?view=diff&rev=504712&r1=504711&r2=504712
==============================================================================
--- webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/proxy/GorillaDLWProxyTests.java (original)
+++ webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/proxy/GorillaDLWProxyTests.java Wed Feb  7 14:06:01 2007
@@ -18,24 +18,22 @@
  */
 package org.apache.axis2.jaxws.proxy;
 
-import java.io.File;
-import java.net.MalformedURLException;
-import java.net.URL;
-import java.util.ArrayList;
-import java.util.List;
+import junit.framework.Test;
+import junit.framework.TestSuite;
+import org.apache.axis2.jaxws.framework.AbstractTestCase;
+import org.apache.axis2.jaxws.proxy.gorilla_dlw.sei.GorillaInterface;
 
-import javax.xml.bind.JAXBContext;
-import javax.xml.bind.JAXBElement;
-import javax.xml.bind.Marshaller;
 import javax.xml.namespace.QName;
 import javax.xml.ws.BindingProvider;
 import javax.xml.ws.Dispatch;
 import javax.xml.ws.Service;
+import java.io.File;
+import java.net.MalformedURLException;
+import java.net.URL;
+import java.util.ArrayList;
+import java.util.List;
 
-import junit.framework.TestCase;
-import org.apache.axis2.jaxws.proxy.gorilla_dlw.sei.GorillaInterface;
-
-public class GorillaDLWProxyTests extends TestCase {
+public class GorillaDLWProxyTests extends AbstractTestCase {
 
     private QName serviceName = new QName(
             "http://org.apache.axis2.jaxws.proxy.gorilla_dlw", "GorillaService");
@@ -44,6 +42,10 @@
             "GorillaPort");
     private String wsdlLocation = System.getProperty("basedir",".")+"/"+"test/org/apache/axis2/jaxws/proxy/gorilla_dlw/META-INF/gorilla_dlw.wsdl";
     
+    public static Test suite() {
+        return getTestSetup(new TestSuite(GorillaDLWProxyTests.class));
+    }
+
     /**
      * Utility method to get the proxy
      * @return GorillaInterface proxy

Modified: webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/proxy/ProxyNonWrappedTests.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/proxy/ProxyNonWrappedTests.java?view=diff&rev=504712&r1=504711&r2=504712
==============================================================================
--- webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/proxy/ProxyNonWrappedTests.java (original)
+++ webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/proxy/ProxyNonWrappedTests.java Wed Feb  7 14:06:01 2007
@@ -28,8 +28,11 @@
 import javax.xml.ws.Service;
 
 import junit.framework.TestCase;
+import junit.framework.Test;
+import junit.framework.TestSuite;
 import org.apache.axis2.jaxws.proxy.doclitnonwrapped.sei.DocLitnonWrappedProxy;
 import org.apache.axis2.jaxws.proxy.doclitnonwrapped.sei.ProxyDocLitUnwrappedService;
+import org.apache.axis2.jaxws.framework.AbstractTestCase;
 import org.test.proxy.doclitnonwrapped.Invoke;
 import org.test.proxy.doclitnonwrapped.ObjectFactory;
 import org.test.proxy.doclitnonwrapped.ReturnType;
@@ -38,7 +41,7 @@
  * This test cases will use proxy NON wrapped wsdl to invoke methods
  * on a deployed Server Endpoint.
  */
-public class ProxyNonWrappedTests extends TestCase {
+public class ProxyNonWrappedTests extends AbstractTestCase {
 
     QName serviceName = new QName("http://doclitnonwrapped.proxy.test.org", "ProxyDocLitUnwrappedService");
     private String axisEndpoint = "http://localhost:8080/axis2/services/ProxyDocLitUnwrappedService";
@@ -57,6 +60,10 @@
         // TODO Auto-generated constructor stub
     }
     
+    public static Test suite() {
+        return getTestSetup(new TestSuite(ProxyNonWrappedTests.class));
+    }
+
     public void testInvoke(){
         System.out.println("-----------------------------------");
         System.out.println("test: " + getName());

Modified: webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/proxy/ProxyTests.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/proxy/ProxyTests.java?view=diff&rev=504712&r1=504711&r2=504712
==============================================================================
--- webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/proxy/ProxyTests.java (original)
+++ webservices/axis2/trunk/java/modules/jaxws/test/org/apache/axis2/jaxws/proxy/ProxyTests.java Wed Feb  7 14:06:01 2007
@@ -29,11 +29,14 @@
 import javax.xml.ws.Service;
 
 import junit.framework.TestCase;
+import junit.framework.Test;
+import junit.framework.TestSuite;
 import org.apache.axis2.jaxws.proxy.doclitwrapped.sei.DocLitWrappedProxy;
 import org.apache.axis2.jaxws.proxy.doclitwrapped.sei.ProxyDocLitWrappedService;
+import org.apache.axis2.jaxws.framework.AbstractTestCase;
 import org.test.proxy.doclitwrapped.ReturnType;
 
-public class ProxyTests extends TestCase {
+public class ProxyTests extends AbstractTestCase {
     private QName serviceName = new QName(
             "http://doclitwrapped.proxy.test.org", "ProxyDocLitWrappedService");
     private String axisEndpoint = "http://localhost:8080/axis2/services/ProxyDocLitWrappedService";
@@ -42,6 +45,10 @@
     private String wsdlLocation = System.getProperty("basedir",".")+"/"+"test/org/apache/axis2/jaxws/proxy/doclitwrapped/META-INF/ProxyDocLitWrapped.wsdl";
     private boolean runningOnAxis = true;
     
+    public static Test suite() {
+        return getTestSetup(new TestSuite(ProxyTests.class));
+    }
+
     public void testMultipleServiceCalls(){
         try{
             if(!runningOnAxis){



---------------------------------------------------------------------
To unsubscribe, e-mail: axis-cvs-unsubscribe@ws.apache.org
For additional commands, e-mail: axis-cvs-help@ws.apache.org
--- webservices/axis2/trunk/java/modules/jaxws/src/org/apache/axis2/jaxws/client/JAXBDispatch.java (original)
+++ webservices/axis2/trunk/java/modules/jaxws/src/org/apache/axis2/jaxws/client/JAXBDispatch.java Wed Feb  7 14:06:01 2007
@@ -103,7 +103,7 @@
     }
     
     /**
      * Common code to get the value for JAXBDispatch and JAXBDispatchAsyncListener
      * @param message
      * @param mode
      * @param jaxbContext
@@ -124,7 +124,7 @@
                     // REVIEW This seems like the correct behavior.  If the body is empty, return a null
                     // Any changes here should also be made to XMLDispatch.getValue
                     if (log.isDebugEnabled()) {
-                        log.debug("There are no elements in the body to unmarshal.  JAXBDispatch returns a null value");
+                        log.debug("There are no elements in the body to unmarshal.  JAXBDispatchTest returns a null value");
                     }
                     value = null;
                 }
@@ -103,7 +103,7 @@
     
     /**
-     * Common code to get the value for JAXBDispatch and JAXBDispatchAsyncListener
+     * Common code to get the value for JAXBDispatchTest and JAXBDispatchAsyncListener
      * @param message
      * @param mode

Modified: webservices/axis2/trunk/java/modules/jaxws/src/org/apache/axis2/jaxws/client/XMLDispatch.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/jaxws/src/org/apache/axis2/jaxws/client/XMLDispatch.java?view=diff&rev=504712&r1=504711&r2=504712
==============================================================================